# ng2nlm - Turn a Norton Guide into a source for NotebookLM

## Introduction

`ng2nlm` is a tool for turning a Norton Guide file into a source that can be
used with NotebooLM (or similar LLM tools).

[//]: # (README.md ends here)
